@@ -7,13 +7,13 @@ import threading
 import json
 from .udp_message import create_start_transaction_message, create_end_transaction_message
 from .udp_message import create_method_entry_message, create_method_exit_message
+from .udp_message import create_transaction_encode_http_message
 from .udp_message import create_havoc_message
 from .udp_message import create_init_message
 from .udp_message import create_heartbeat_message
 import time
 import logging
 
-# from .udp_message import create_transaction_encode_http_message
 udp_connection = None
 
 logger = logging.getLogger('pythonagent.agent')
@@ -77,7 +77,7 @@ def heartbeat_sender(udp_socket, address_port, ag_obj):
             time.sleep(10)
             logger.debug("heartbeat sleep completed")
         except Exception as e:
-            logger.error("heartbeat exception {}".format(e))
+            logger.error("heartbeat exception", e)
 
 
 def incoming_message_processor(udp_socket):
@@ -135,12 +135,11 @@ def incoming_message_processor(udp_socket):
                 havoc_monitor.parse_nethavoc_config(body, header_dict)
 
             except Exception as e:
-                logger.warning("Unable to parse config: {}".format(e))
+                logger.warning("Unable to parse config: {}", e)
                 logger.warning("unable to parse message except")
 
         except socket.timeout:
             logger.debug("recv timed out")  # This is not an exception, but a mechanism to implement timeout
-            logger.warning("timed out after recvfrom")
 
 
 def generate_bt():
@@ -231,6 +230,11 @@ def http_call_begin(agent_obj, bt, http_host, url):
 def http_call_end(agent_obj, bt, ip_handle):
     pass
 
+def http_req_resp_wrapper(agent_obj, bt, rbuffer, rtype, statuscode):
+    context = agent_obj.get_transaction_context()
+    message = create_transaction_encode_http_message(context, bt, rbuffer, rtype, statuscode)
+    logger.info("transaction_encode_http message {}".format(message))
+    agent_obj.udp_connection.send(message)
 
 def havoc_message(agent_obj, havoc_header):
     context = agent_obj.get_transaction_context()
