@@ -18,7 +18,6 @@ from werkzeug.wrappers import Request ,Response
 from pyclbr import readmodule
 import os
 import inspect
-import logging
 import cProfile
 import pstats
 from pythonagent.agent.probes.frameworks.test import dumpstacks
@@ -34,9 +33,6 @@ from pythonagent.agent.probes.frameworks.aisess import Aisession
 #os.environ['Aisession_flag'] = 'True'
 
 #profiler = None
-logger = logging.getLogger('pythonagent.agent')
-
-
 def aiflagset(s,st,d,sname):
     os.environ['Aisession_flag'] = 'True'   
     global duration
@@ -57,13 +53,11 @@ class WSGIInterceptor(EntryPointInterceptor):
         # bt = self.start_transaction(ENTRY_WSGI, LazyWsgiRequest(environ))
         stack = inspect.stack()
         temp = {}
-        logger.info("the_method in wsgi.py ------------------------>>>>>>>>>>>>{}".format(stack))
         the_method_called = stack[3][0].f_code.co_name
-        logger.info("the_method in wsgi.py ------------------>>>>>>>>>>>>>>>>>>>>>>{}".format(the_method_called))
+        print("the_method in wsgi.py ------------------>>>>>>>>>>>>>>>>>>>>>>",the_method_called)
 
         request = Request(environ)
         
-        
         #thread dump captured
         #dumpstacks()
 
@@ -77,6 +71,8 @@ class WSGIInterceptor(EntryPointInterceptor):
             profiler.disableprof()
 
         bt = self.start_business_transaction(request.full_path, '')
+        req_headers = self.parse_headers(request.headers.items())
+        self.agent.http_req_resp_wrapper(bt, req_headers, "req", 200)
 
         self.agent.logger.debug("Modulename: WSGI interceptor class || bt value is :{0}".format(bt)) 
 
@@ -110,6 +106,13 @@ class WSGIInterceptor(EntryPointInterceptor):
             #See https://www.python.org/dev/peps/pep-0333/#the-start-response-callable for more information.
             with self.log_exceptions():
                 bt = self.bt
+                resp_headers = self.parse_headers(headers.copy())
+
+                #traceparent_bytes, tracestate_bytes = self.agent.get_trace_headers(bt)
+                #telemetry_headers = "|Traceparent$" + traceparent_bytes.decode() + "|Tracestate$" + tracestate_bytes.decode()
+                #resp_headers = resp_headers + telemetry_headers
+
+                self.agent.http_req_resp_wrapper(bt, resp_headers, "resp", 200)
                 self.agent.logger.info("Modulename: WSGI interceptor class || bt value is :{0}".format(bt))
 
                 if bt:
@@ -125,6 +128,18 @@ class WSGIInterceptor(EntryPointInterceptor):
         return start_response_wrapper
 
 
+    def parse_headers(self, input_list):
+        output_str = ""
+        for key, value in input_list:
+            new_str = key + "$" + value + "|"
+            output_str += new_str
+        output_str = output_str[:-1]  # Remove last |
+        output_str = output_str.replace("=", "$")
+        # output_str = output_str.replace("&", "|")
+
+        return output_str
+
+
 class WSGIMiddleware(object):
     #self.agent.logger.info('Modulename: WSGIMiddleware class ')
     def __init__(self, application=None):
